==> open-xchange-core_7.8.4.orig.tar.bz2: open-xchange-core-7.8.4/com.openexchange.serverconfig.impl/src/com/openexchange/serverconfig/impl/osgi/ServerConfigActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.serverconfig.impl.osgi;

import java.util.Collections;
import java.util.List;
import com.openexchange.capabilities.CapabilityService;
import com.openexchange.config.ConfigurationService;
import com.openexchange.config.ForcedReloadable;
import com.openexchange.config.Interests;
import com.openexchange.config.cascade.ConfigViewFactory;
import com.openexchange.conversion.simple.SimpleConverter;
import com.openexchange.dispatcher.DispatcherPrefixService;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.osgi.NearRegistryServiceTracker;
import com.openexchange.serverconfig.ClientServerConfigFilter;
import com.openexchange.serverconfig.ComputedServerConfigValueService;
import com.openexchange.serverconfig.ServerConfigService;
import com.openexchange.serverconfig.ServerConfigServicesLookup;
import com.openexchange.serverconfig.impl.ServerConfigServiceImpl;
import com.openexchange.serverconfig.impl.values.Capabilities;
import com.openexchange.serverconfig.impl.values.ForcedHttpsValue;
import com.openexchange.serverconfig.impl.values.Hosts;
import com.openexchange.serverconfig.impl.values.Languages;
import com.openexchange.serverconfig.impl.values.Prefix;
import com.openexchange.serverconfig.impl.values.ServerVersion;
import com.openexchange.tools.session.SessionHolder;

/**
 * {@link ServerConfigActivator}
 */
public class ServerConfigActivator extends HousekeepingActivator {

    /**
     * Initializes a new {@link ServerConfigActivator}.
     */
    public ServerConfigActivator() {
        super();
    }

    @Override
    protected boolean stopOnServiceUnavailability() {
        return true;
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class[] {ConfigurationService.class, ConfigViewFactory.class, CapabilityService.class, SimpleConverter.class};
    }

    @Override
    protected void startBundle() throws Exception {

        final NearRegistryServiceTracker<ComputedServerConfigValueService> computedValueTracker = new NearRegistryServiceTracker<ComputedServerConfigValueService>(
            context,
            ComputedServerConfigValueService.class);
        rememberTracker(computedValueTracker);

        final NearRegistryServiceTracker<ClientServerConfigFilter> configFilterTracker = new NearRegistryServiceTracker<ClientServerConfigFilter>(
            context,
            ClientServerConfigFilter.class
        );
        rememberTracker(configFilterTracker);
        trackService(DispatcherPrefixService.class);
        trackService(SessionHolder.class);
        openTrackers();

        ServerConfigServicesLookup serverConfigServicesLookup = new ServerConfigServicesLookup() {

            @Override
            public List<ComputedServerConfigValueService> getComputed() {
                return Collections.unmodifiableList(computedValueTracker.getServiceList());
            }

            @Override
            public List<ClientServerConfigFilter> getClientFilters() {
                return configFilterTracker.getServiceList();
            }

        };

        registerService(ForcedReloadable.class, new ForcedReloadable() {

            @Override
            public void reloadConfiguration(ConfigurationService configService) {
                ServerConfigServiceImpl.invalidateCache();
            }

            @Override
            public Interests getInterests() {
                return null;
            }
        });

        // Register the services that add computed values during creation of the server config
        registerService(ComputedServerConfigValueService.class, new ForcedHttpsValue(this));
        registerService(ComputedServerConfigValueService.class, new Hosts());
        registerService(ComputedServerConfigValueService.class, new Languages(this));
        registerService(ComputedServerConfigValueService.class, new ServerVersion());
        registerService(ComputedServerConfigValueService.class, new Capabilities(this));
        registerService(ComputedServerConfigValueService.class, new Prefix(this));

        // The actual config service
        ServerConfigServiceImpl serverConfigServiceImpl = new ServerConfigServiceImpl(this, serverConfigServicesLookup);
        registerService(ServerConfigService.class, serverConfigServiceImpl);
    }

}

==> open-xchange-core_7.10.0.orig.tar.bz2: open-xchange-core-7.10.0/com.openexchange.serverconfig.impl/src/com/openexchange/serverconfig/impl/osgi/ServerConfigActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.serverconfig.impl.osgi;

import java.util.Collections;
import java.util.List;
import com.openexchange.capabilities.CapabilityService;
import com.openexchange.config.ConfigurationService;
import com.openexchange.config.ForcedReloadable;
import com.openexchange.config.Interests;
import com.openexchange.config.cascade.ConfigViewFactory;
import com.openexchange.dispatcher.DispatcherPrefixService;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.osgi.NearRegistryServiceTracker;
import com.openexchange.serverconfig.ClientServerConfigFilter;
import com.openexchange.serverconfig.ComputedServerConfigValueService;
import com.openexchange.serverconfig.ServerConfigService;
import com.openexchange.serverconfig.ServerConfigServicesLookup;
import com.openexchange.serverconfig.impl.ServerConfigServiceImpl;
import com.openexchange.serverconfig.impl.values.Capabilities;
import com.openexchange.serverconfig.impl.values.ForcedHttpsValue;
import com.openexchange.serverconfig.impl.values.Hosts;
import com.openexchange.serverconfig.impl.values.Languages;
import com.openexchange.serverconfig.impl.values.Prefix;
import com.openexchange.serverconfig.impl.values.ServerVersion;
import com.openexchange.tools.session.SessionHolder;

/**
 * {@link ServerConfigActivator}
 */
public class ServerConfigActivator extends HousekeepingActivator {

    /**
     * Initializes a new {@link ServerConfigActivator}.
     */
    public ServerConfigActivator() {
        super();
    }

    @Override
    protected boolean stopOnServiceUnavailability() {
        return true;
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class[] { ConfigurationService.class, ConfigViewFactory.class, CapabilityService.class };
    }

    @Override
    protected void startBundle() throws Exception {

        final NearRegistryServiceTracker<ComputedServerConfigValueService> computedValueTracker = new NearRegistryServiceTracker<ComputedServerConfigValueService>(
            context,
            ComputedServerConfigValueService.class);
        rememberTracker(computedValueTracker);

        final NearRegistryServiceTracker<ClientServerConfigFilter> configFilterTracker = new NearRegistryServiceTracker<ClientServerConfigFilter>(
            context,
            ClientServerConfigFilter.class
        );
        rememberTracker(configFilterTracker);
        trackService(DispatcherPrefixService.class);
        trackService(SessionHolder.class);
        openTrackers();

        ServerConfigServicesLookup serverConfigServicesLookup = new ServerConfigServicesLookup() {

            @Override
            public List<ComputedServerConfigValueService> getComputed() {
                return Collections.unmodifiableList(computedValueTracker.getServiceList());
            }

            @Override
            public List<ClientServerConfigFilter> getClientFilters() {
                return configFilterTracker.getServiceList();
            }

        };

        registerService(ForcedReloadable.class, new ForcedReloadable() {

            @Override
            public void reloadConfiguration(ConfigurationService configService) {
                ServerConfigServiceImpl.invalidateCache();
            }

            @Override
            public Interests getInterests() {
                return null;
            }
        });

        // Register the services that add computed values during creation of the server config
        registerService(ComputedServerConfigValueService.class, new ForcedHttpsValue(this));
        registerService(ComputedServerConfigValueService.class, new Hosts());
        registerService(ComputedServerConfigValueService.class, new Languages(this));
        registerService(ComputedServerConfigValueService.class, new ServerVersion());
        registerService(ComputedServerConfigValueService.class, new Capabilities(this));
        registerService(ComputedServerConfigValueService.class, new Prefix(this));

        // The actual config service
        ServerConfigServiceImpl serverConfigServiceImpl = new ServerConfigServiceImpl(this, serverConfigServicesLookup);
        registerService(ServerConfigService.class, serverConfigServiceImpl);
    }

}
